# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transactionBase.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='transactionBase.proto',
  package='transactionbasepb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x15transactionBase.proto\x12\x11transactionbasepb\"L\n\x07TXInput\x12\x0c\n\x04txid\x18\x01 \x01(\x0c\x12\x0c\n\x04vout\x18\x02 \x01(\x05\x12\x11\n\tsignature\x18\x03 \x01(\x0c\x12\x12\n\npublic_key\x18\x04 \x01(\x0c\"D\n\x08TXOutput\x12\r\n\x05value\x18\x01 \x01(\x0c\x12\x17\n\x0fpublic_key_hash\x18\x02 \x01(\x0c\x12\x10\n\x08\x63ontract\x18\x03 \x01(\tb\x06proto3'
)




_TXINPUT = _descriptor.Descriptor(
  name='TXInput',
  full_name='transactionbasepb.TXInput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='txid', full_name='transactionbasepb.TXInput.txid', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vout', full_name='transactionbasepb.TXInput.vout', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='signature', full_name='transactionbasepb.TXInput.signature', index=2,
      number=3, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key', full_name='transactionbasepb.TXInput.public_key', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=44,
  serialized_end=120,
)


_TXOUTPUT = _descriptor.Descriptor(
  name='TXOutput',
  full_name='transactionbasepb.TXOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='transactionbasepb.TXOutput.value', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='public_key_hash', full_name='transactionbasepb.TXOutput.public_key_hash', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='contract', full_name='transactionbasepb.TXOutput.contract', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=122,
  serialized_end=190,
)

DESCRIPTOR.message_types_by_name['TXInput'] = _TXINPUT
DESCRIPTOR.message_types_by_name['TXOutput'] = _TXOUTPUT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TXInput = _reflection.GeneratedProtocolMessageType('TXInput', (_message.Message,), {
  'DESCRIPTOR' : _TXINPUT,
  '__module__' : 'transactionBase_pb2'
  # @@protoc_insertion_point(class_scope:transactionbasepb.TXInput)
  })
_sym_db.RegisterMessage(TXInput)

TXOutput = _reflection.GeneratedProtocolMessageType('TXOutput', (_message.Message,), {
  'DESCRIPTOR' : _TXOUTPUT,
  '__module__' : 'transactionBase_pb2'
  # @@protoc_insertion_point(class_scope:transactionbasepb.TXOutput)
  })
_sym_db.RegisterMessage(TXOutput)


# @@protoc_insertion_point(module_scope)
