# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: transaction.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import transactionBase_pb2 as transactionBase__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='transaction.proto',
  package='transactionpb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x11transaction.proto\x12\rtransactionpb\x1a\x15transactionBase.proto\"@\n\x0cTransactions\x12\x30\n\x0ctransactions\x18\x01 \x03(\x0b\x32\x1a.transactionpb.Transaction\"\xae\x01\n\x0bTransaction\x12\n\n\x02id\x18\x01 \x01(\x0c\x12\'\n\x03vin\x18\x02 \x03(\x0b\x32\x1a.transactionbasepb.TXInput\x12)\n\x04vout\x18\x03 \x03(\x0b\x32\x1b.transactionbasepb.TXOutput\x12\x0b\n\x03tip\x18\x04 \x01(\x0c\x12\x11\n\tgas_limit\x18\x05 \x01(\x0c\x12\x11\n\tgas_price\x18\x06 \x01(\x0c\x12\x0c\n\x04type\x18\x07 \x01(\x05\"\xd7\x01\n\x0fTransactionNode\x12>\n\x08\x63hildren\x18\x01 \x03(\x0b\x32,.transactionpb.TransactionNode.ChildrenEntry\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.transactionpb.Transaction\x12\x0c\n\x04size\x18\x03 \x01(\x03\x1aK\n\rChildrenEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12)\n\x05value\x18\x02 \x01(\x0b\x32\x1a.transactionpb.Transaction:\x02\x38\x01\"?\n\x12TransactionJournal\x12)\n\x04vout\x18\x01 \x03(\x0b\x32\x1b.transactionbasepb.TXOutputb\x06proto3'
  ,
  dependencies=[transactionBase__pb2.DESCRIPTOR,])




_TRANSACTIONS = _descriptor.Descriptor(
  name='Transactions',
  full_name='transactionpb.Transactions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transactions', full_name='transactionpb.Transactions.transactions', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=59,
  serialized_end=123,
)


_TRANSACTION = _descriptor.Descriptor(
  name='Transaction',
  full_name='transactionpb.Transaction',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='transactionpb.Transaction.id', index=0,
      number=1, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vin', full_name='transactionpb.Transaction.vin', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vout', full_name='transactionpb.Transaction.vout', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tip', full_name='transactionpb.Transaction.tip', index=3,
      number=4, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_limit', full_name='transactionpb.Transaction.gas_limit', index=4,
      number=5, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='gas_price', full_name='transactionpb.Transaction.gas_price', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=b"",
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='transactionpb.Transaction.type', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=126,
  serialized_end=300,
)


_TRANSACTIONNODE_CHILDRENENTRY = _descriptor.Descriptor(
  name='ChildrenEntry',
  full_name='transactionpb.TransactionNode.ChildrenEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='transactionpb.TransactionNode.ChildrenEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='transactionpb.TransactionNode.ChildrenEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=443,
  serialized_end=518,
)

_TRANSACTIONNODE = _descriptor.Descriptor(
  name='TransactionNode',
  full_name='transactionpb.TransactionNode',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='children', full_name='transactionpb.TransactionNode.children', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='transactionpb.TransactionNode.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='transactionpb.TransactionNode.size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TRANSACTIONNODE_CHILDRENENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=303,
  serialized_end=518,
)


_TRANSACTIONJOURNAL = _descriptor.Descriptor(
  name='TransactionJournal',
  full_name='transactionpb.TransactionJournal',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vout', full_name='transactionpb.TransactionJournal.vout', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=583,
)

_TRANSACTIONS.fields_by_name['transactions'].message_type = _TRANSACTION
_TRANSACTION.fields_by_name['vin'].message_type = transactionBase__pb2._TXINPUT
_TRANSACTION.fields_by_name['vout'].message_type = transactionBase__pb2._TXOUTPUT
_TRANSACTIONNODE_CHILDRENENTRY.fields_by_name['value'].message_type = _TRANSACTION
_TRANSACTIONNODE_CHILDRENENTRY.containing_type = _TRANSACTIONNODE
_TRANSACTIONNODE.fields_by_name['children'].message_type = _TRANSACTIONNODE_CHILDRENENTRY
_TRANSACTIONNODE.fields_by_name['value'].message_type = _TRANSACTION
_TRANSACTIONJOURNAL.fields_by_name['vout'].message_type = transactionBase__pb2._TXOUTPUT
DESCRIPTOR.message_types_by_name['Transactions'] = _TRANSACTIONS
DESCRIPTOR.message_types_by_name['Transaction'] = _TRANSACTION
DESCRIPTOR.message_types_by_name['TransactionNode'] = _TRANSACTIONNODE
DESCRIPTOR.message_types_by_name['TransactionJournal'] = _TRANSACTIONJOURNAL
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Transactions = _reflection.GeneratedProtocolMessageType('Transactions', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONS,
  '__module__' : 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:transactionpb.Transactions)
  })
_sym_db.RegisterMessage(Transactions)

Transaction = _reflection.GeneratedProtocolMessageType('Transaction', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTION,
  '__module__' : 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:transactionpb.Transaction)
  })
_sym_db.RegisterMessage(Transaction)

TransactionNode = _reflection.GeneratedProtocolMessageType('TransactionNode', (_message.Message,), {

  'ChildrenEntry' : _reflection.GeneratedProtocolMessageType('ChildrenEntry', (_message.Message,), {
    'DESCRIPTOR' : _TRANSACTIONNODE_CHILDRENENTRY,
    '__module__' : 'transaction_pb2'
    # @@protoc_insertion_point(class_scope:transactionpb.TransactionNode.ChildrenEntry)
    })
  ,
  'DESCRIPTOR' : _TRANSACTIONNODE,
  '__module__' : 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:transactionpb.TransactionNode)
  })
_sym_db.RegisterMessage(TransactionNode)
_sym_db.RegisterMessage(TransactionNode.ChildrenEntry)

TransactionJournal = _reflection.GeneratedProtocolMessageType('TransactionJournal', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONJOURNAL,
  '__module__' : 'transaction_pb2'
  # @@protoc_insertion_point(class_scope:transactionpb.TransactionJournal)
  })
_sym_db.RegisterMessage(TransactionJournal)


_TRANSACTIONNODE_CHILDRENENTRY._options = None
# @@protoc_insertion_point(module_scope)
