# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: datastore.proto

from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import peer_pb2 as peer__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='datastore.proto',
  package='metricspb',
  syntax='proto3',
  serialized_options=None,
  serialized_pb=b'\n\x0f\x64\x61tastore.proto\x12\tmetricspb\x1a\npeer.proto\"\xe7\x01\n\x04Stat\x12\x11\n\ttimestamp\x18\x01 \x01(\x03\x12\x1f\n\x15transaction_pool_size\x18\x02 \x01(\x03H\x00\x12.\n\x0cmemory_stats\x18\x03 \x01(\x0b\x32\x16.metricspb.MemoryStatsH\x00\x12\x18\n\x0e\x63pu_percentage\x18\x04 \x01(\x01H\x00\x12*\n\nfork_stats\x18\x05 \x01(\x0b\x32\x14.metricspb.ForkStatsH\x00\x12,\n\x0b\x62lock_stats\x18\x06 \x01(\x0b\x32\x15.metricspb.BlockStatsH\x00\x42\x07\n\x05value\"4\n\x0bMemoryStats\x12\x13\n\x0bheap_in_use\x18\x01 \x01(\x04\x12\x10\n\x08heap_sys\x18\x02 \x01(\x04\"4\n\tForkStats\x12\x11\n\tnum_forks\x18\x01 \x01(\x03\x12\x14\n\x0clongest_fork\x18\x02 \x01(\x03\"6\n\nBlockStats\x12\x18\n\x10num_transactions\x18\x01 \x01(\x04\x12\x0e\n\x06height\x18\x02 \x01(\x04\"(\n\x06Metric\x12\x1e\n\x05stats\x18\x01 \x03(\x0b\x32\x0f.metricspb.Stat\"\x82\x01\n\tDataStore\x12\x32\n\x07metrics\x18\x01 \x03(\x0b\x32!.metricspb.DataStore.MetricsEntry\x1a\x41\n\x0cMetricsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12 \n\x05value\x18\x02 \x01(\x0b\x32\x11.metricspb.Metric:\x02\x38\x01\"\x83\x01\n\x07Metrics\x12(\n\ndata_store\x18\x01 \x01(\x0b\x32\x14.metricspb.DataStore\x12\"\n\x05peers\x18\x02 \x03(\x0b\x32\x13.networkpb.PeerInfo\x12*\n\x0b\x62lock_stats\x18\x03 \x03(\x0b\x32\x15.metricspb.BlockStatsb\x06proto3'
  ,
  dependencies=[peer__pb2.DESCRIPTOR,])




_STAT = _descriptor.Descriptor(
  name='Stat',
  full_name='metricspb.Stat',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='metricspb.Stat.timestamp', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transaction_pool_size', full_name='metricspb.Stat.transaction_pool_size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='memory_stats', full_name='metricspb.Stat.memory_stats', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cpu_percentage', full_name='metricspb.Stat.cpu_percentage', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fork_stats', full_name='metricspb.Stat.fork_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_stats', full_name='metricspb.Stat.block_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='metricspb.Stat.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=43,
  serialized_end=274,
)


_MEMORYSTATS = _descriptor.Descriptor(
  name='MemoryStats',
  full_name='metricspb.MemoryStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='heap_in_use', full_name='metricspb.MemoryStats.heap_in_use', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='heap_sys', full_name='metricspb.MemoryStats.heap_sys', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=276,
  serialized_end=328,
)


_FORKSTATS = _descriptor.Descriptor(
  name='ForkStats',
  full_name='metricspb.ForkStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_forks', full_name='metricspb.ForkStats.num_forks', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='longest_fork', full_name='metricspb.ForkStats.longest_fork', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=330,
  serialized_end=382,
)


_BLOCKSTATS = _descriptor.Descriptor(
  name='BlockStats',
  full_name='metricspb.BlockStats',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num_transactions', full_name='metricspb.BlockStats.num_transactions', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='height', full_name='metricspb.BlockStats.height', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=384,
  serialized_end=438,
)


_METRIC = _descriptor.Descriptor(
  name='Metric',
  full_name='metricspb.Metric',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stats', full_name='metricspb.Metric.stats', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=440,
  serialized_end=480,
)


_DATASTORE_METRICSENTRY = _descriptor.Descriptor(
  name='MetricsEntry',
  full_name='metricspb.DataStore.MetricsEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='metricspb.DataStore.MetricsEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='metricspb.DataStore.MetricsEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=548,
  serialized_end=613,
)

_DATASTORE = _descriptor.Descriptor(
  name='DataStore',
  full_name='metricspb.DataStore',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='metrics', full_name='metricspb.DataStore.metrics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_DATASTORE_METRICSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=483,
  serialized_end=613,
)


_METRICS = _descriptor.Descriptor(
  name='Metrics',
  full_name='metricspb.Metrics',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_store', full_name='metricspb.Metrics.data_store', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='peers', full_name='metricspb.Metrics.peers', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='block_stats', full_name='metricspb.Metrics.block_stats', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=616,
  serialized_end=747,
)

_STAT.fields_by_name['memory_stats'].message_type = _MEMORYSTATS
_STAT.fields_by_name['fork_stats'].message_type = _FORKSTATS
_STAT.fields_by_name['block_stats'].message_type = _BLOCKSTATS
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['transaction_pool_size'])
_STAT.fields_by_name['transaction_pool_size'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['memory_stats'])
_STAT.fields_by_name['memory_stats'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['cpu_percentage'])
_STAT.fields_by_name['cpu_percentage'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['fork_stats'])
_STAT.fields_by_name['fork_stats'].containing_oneof = _STAT.oneofs_by_name['value']
_STAT.oneofs_by_name['value'].fields.append(
  _STAT.fields_by_name['block_stats'])
_STAT.fields_by_name['block_stats'].containing_oneof = _STAT.oneofs_by_name['value']
_METRIC.fields_by_name['stats'].message_type = _STAT
_DATASTORE_METRICSENTRY.fields_by_name['value'].message_type = _METRIC
_DATASTORE_METRICSENTRY.containing_type = _DATASTORE
_DATASTORE.fields_by_name['metrics'].message_type = _DATASTORE_METRICSENTRY
_METRICS.fields_by_name['data_store'].message_type = _DATASTORE
_METRICS.fields_by_name['peers'].message_type = peer__pb2._PEERINFO
_METRICS.fields_by_name['block_stats'].message_type = _BLOCKSTATS
DESCRIPTOR.message_types_by_name['Stat'] = _STAT
DESCRIPTOR.message_types_by_name['MemoryStats'] = _MEMORYSTATS
DESCRIPTOR.message_types_by_name['ForkStats'] = _FORKSTATS
DESCRIPTOR.message_types_by_name['BlockStats'] = _BLOCKSTATS
DESCRIPTOR.message_types_by_name['Metric'] = _METRIC
DESCRIPTOR.message_types_by_name['DataStore'] = _DATASTORE
DESCRIPTOR.message_types_by_name['Metrics'] = _METRICS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Stat = _reflection.GeneratedProtocolMessageType('Stat', (_message.Message,), {
  'DESCRIPTOR' : _STAT,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.Stat)
  })
_sym_db.RegisterMessage(Stat)

MemoryStats = _reflection.GeneratedProtocolMessageType('MemoryStats', (_message.Message,), {
  'DESCRIPTOR' : _MEMORYSTATS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.MemoryStats)
  })
_sym_db.RegisterMessage(MemoryStats)

ForkStats = _reflection.GeneratedProtocolMessageType('ForkStats', (_message.Message,), {
  'DESCRIPTOR' : _FORKSTATS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.ForkStats)
  })
_sym_db.RegisterMessage(ForkStats)

BlockStats = _reflection.GeneratedProtocolMessageType('BlockStats', (_message.Message,), {
  'DESCRIPTOR' : _BLOCKSTATS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.BlockStats)
  })
_sym_db.RegisterMessage(BlockStats)

Metric = _reflection.GeneratedProtocolMessageType('Metric', (_message.Message,), {
  'DESCRIPTOR' : _METRIC,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.Metric)
  })
_sym_db.RegisterMessage(Metric)

DataStore = _reflection.GeneratedProtocolMessageType('DataStore', (_message.Message,), {

  'MetricsEntry' : _reflection.GeneratedProtocolMessageType('MetricsEntry', (_message.Message,), {
    'DESCRIPTOR' : _DATASTORE_METRICSENTRY,
    '__module__' : 'datastore_pb2'
    # @@protoc_insertion_point(class_scope:metricspb.DataStore.MetricsEntry)
    })
  ,
  'DESCRIPTOR' : _DATASTORE,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.DataStore)
  })
_sym_db.RegisterMessage(DataStore)
_sym_db.RegisterMessage(DataStore.MetricsEntry)

Metrics = _reflection.GeneratedProtocolMessageType('Metrics', (_message.Message,), {
  'DESCRIPTOR' : _METRICS,
  '__module__' : 'datastore_pb2'
  # @@protoc_insertion_point(class_scope:metricspb.Metrics)
  })
_sym_db.RegisterMessage(Metrics)


_DATASTORE_METRICSENTRY._options = None
# @@protoc_insertion_point(module_scope)
